==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkFixedWidthTextReader.java <==
// java wrapper for vtkFixedWidthTextReader object
//

package vtk;
import vtk.*;

public class vtkFixedWidthTextReader extends vtkTableAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetFileName_2();
  public String GetFileName()
    { return GetFileName_2(); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native void SetFieldWidth_4(int id0);
  public void SetFieldWidth(int id0)
    { SetFieldWidth_4(id0); }

  private native int GetFieldWidth_5();
  public int GetFieldWidth()
    { return GetFieldWidth_5(); }

  private native void SetStripWhiteSpace_6(boolean id0);
  public void SetStripWhiteSpace(boolean id0)
    { SetStripWhiteSpace_6(id0); }

  private native boolean GetStripWhiteSpace_7();
  public boolean GetStripWhiteSpace()
    { return GetStripWhiteSpace_7(); }

  private native void StripWhiteSpaceOn_8();
  public void StripWhiteSpaceOn()
    { StripWhiteSpaceOn_8(); }

  private native void StripWhiteSpaceOff_9();
  public void StripWhiteSpaceOff()
    { StripWhiteSpaceOff_9(); }

  private native boolean GetHaveHeaders_10();
  public boolean GetHaveHeaders()
    { return GetHaveHeaders_10(); }

  private native void SetHaveHeaders_11(boolean id0);
  public void SetHaveHeaders(boolean id0)
    { SetHaveHeaders_11(id0); }

  private native void HaveHeadersOn_12();
  public void HaveHeadersOn()
    { HaveHeadersOn_12(); }

  private native void HaveHeadersOff_13();
  public void HaveHeadersOff()
    { HaveHeadersOff_13(); }

  private native void SetTableErrorObserver_14(vtkCommand id0);
  public void SetTableErrorObserver(vtkCommand id0)
    { SetTableErrorObserver_14(id0); }

  private native long GetTableErrorObserver_15();
  public vtkCommand GetTableErrorObserver() {
    long temp = GetTableErrorObserver_15();

    if (temp == 0) return null;
    return (vtkCommand)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkFixedWidthTextReader() { super(); }

  public vtkFixedWidthTextReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-armv7h.pkg.tar.xz: vtk/vtkFixedWidthTextReader.java <==
// java wrapper for vtkFixedWidthTextReader object
//

package vtk;
import vtk.*;

public class vtkFixedWidthTextReader extends vtkTableAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetFileName_2();
  public String GetFileName()
    { return GetFileName_2(); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native void SetFieldWidth_4(int id0);
  public void SetFieldWidth(int id0)
    { SetFieldWidth_4(id0); }

  private native int GetFieldWidth_5();
  public int GetFieldWidth()
    { return GetFieldWidth_5(); }

  private native void SetStripWhiteSpace_6(boolean id0);
  public void SetStripWhiteSpace(boolean id0)
    { SetStripWhiteSpace_6(id0); }

  private native boolean GetStripWhiteSpace_7();
  public boolean GetStripWhiteSpace()
    { return GetStripWhiteSpace_7(); }

  private native void StripWhiteSpaceOn_8();
  public void StripWhiteSpaceOn()
    { StripWhiteSpaceOn_8(); }

  private native void StripWhiteSpaceOff_9();
  public void StripWhiteSpaceOff()
    { StripWhiteSpaceOff_9(); }

  private native boolean GetHaveHeaders_10();
  public boolean GetHaveHeaders()
    { return GetHaveHeaders_10(); }

  private native void SetHaveHeaders_11(boolean id0);
  public void SetHaveHeaders(boolean id0)
    { SetHaveHeaders_11(id0); }

  private native void HaveHeadersOn_12();
  public void HaveHeadersOn()
    { HaveHeadersOn_12(); }

  private native void HaveHeadersOff_13();
  public void HaveHeadersOff()
    { HaveHeadersOff_13(); }

  private native void SetTableErrorObserver_14(vtkCommand id0);
  public void SetTableErrorObserver(vtkCommand id0)
    { SetTableErrorObserver_14(id0); }

  private native long GetTableErrorObserver_15();
  public vtkCommand GetTableErrorObserver() {
    long temp = GetTableErrorObserver_15();

    if (temp == 0) return null;
    return (vtkCommand)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkFixedWidthTextReader() { super(); }

  public vtkFixedWidthTextReader(long id) { super(id); }
  public native long   VTKInit();

}
